@@ -15,31 +15,27 @@
  *
  * You should have received a copy of the GNU Lesser General Public
  * License along with GNU SASL Library; if not, write to the Free
- * Software Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA
- * 02111-1307 USA
+ * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301, USA.
  *
  */
 
-#ifndef SESSION_H
-#define SESSION_H
+#ifndef DIGEST_MD5_SESSION_H
+# define DIGEST_MD5_SESSION_H
 
-#include "digest-md5.h"
+/* Get token types. */
+#include "tokens.h"
 
-int
-digest_md5_encode (Gsasl_session * sctx,
-		   const char *input, size_t input_len,
-		   char **output, size_t * output_len,
-		   Gsasl_qop qop,
-		   uint32_t sendseqnum,
-		   char key[MD5LEN]);
+extern int digest_md5_encode (const char *input, size_t input_len,
+			      char **output, size_t * output_len,
+			      digest_md5_qop qop,
+			      unsigned long sendseqnum,
+			      char key[DIGEST_MD5_LENGTH]);
 
-int
-digest_md5_decode (Gsasl_session * sctx,
-		   const char *input,
-		   size_t input_len,
-		   char **output, size_t * output_len,
-		   Gsasl_qop qop,
-		   uint32_t readseqnum,
-		   char key[MD5LEN]);
+extern int digest_md5_decode (const char *input, size_t input_len,
+			      char **output, size_t * output_len,
+			      digest_md5_qop qop,
+			      unsigned long readseqnum,
+			      char key[DIGEST_MD5_LENGTH]);
 
-#endif /* SESSION_H */
+#endif /* DIGEST_MD5_SESSION_H */
