@@ -1,5 +1,5 @@
 /* client.c --- SASL mechanism GSSAPI as defined in RFC 2222, client side.
- * Copyright (C) 2002, 2003, 2004  Simon Josefsson
+ * Copyright (C) 2002, 2003, 2004, 2005, 2006  Simon Josefsson
  *
  * This file is part of GNU SASL Library.
  *
@@ -15,8 +15,8 @@
  *
  * You should have received a copy of the GNU Lesser General Public
  * License along with GNU SASL Library; if not, write to the Free
- * Software Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA
- * 02111-1307 USA
+ * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301, USA.
  *
  */
 
@@ -33,7 +33,7 @@
 /* Get specification. */
 #include "x-gssapi.h"
 
-#ifdef USE_GSS
+#ifdef HAVE_LIBGSS
 # include <gss.h>
 #elif HAVE_GSSAPI_H		/* Heimdal GSSAPI */
 # include <gssapi.h>
@@ -46,10 +46,6 @@
 # endif
 #endif
 
-#ifdef HAVE_NETINET_IN_H
-# include <netinet/in.h>
-#endif
-
 struct _Gsasl_gssapi_client_state
 {
   int step;
@@ -221,9 +217,12 @@ _gsasl_gssapi_client_step (Gsasl_session * sctx,
       if (!bufdesc.value)
 	return GSASL_MALLOC_ERROR;
 
-      ((char *) bufdesc.value)[0] = state->qop;
-      memcpy (bufdesc.value + 1, clientwrap + 1, 3);
-      memcpy (bufdesc.value + 4, p, strlen (p));
+      {
+	char *q = bufdesc.value;
+	q[0] = state->qop;
+	memcpy (q + 1, clientwrap + 1, 3);
+	memcpy (q + 4, p, strlen (p));
+      }
 
       maj_stat = gss_wrap (&min_stat, state->context, 0, GSS_C_QOP_DEFAULT,
 			   &bufdesc, &conf_state, &bufdesc2);
@@ -260,6 +259,9 @@ _gsasl_gssapi_client_finish (Gsasl_session * sctx, void *mech_data)
   _Gsasl_gssapi_client_state *state = mech_data;
   OM_uint32 maj_stat, min_stat;
 
+  if (!state)
+    return;
+
   if (state->service != GSS_C_NO_NAME)
     maj_stat = gss_release_name (&min_stat, &state->service);
   if (state->context != GSS_C_NO_CONTEXT)
