@@ -1,5 +1,5 @@
 /* client.c --- Non-standard SASL mechanism LOGIN, client side.
- * Copyright (C) 2002, 2003, 2004  Simon Josefsson
+ * Copyright (C) 2002, 2003, 2004, 2006  Simon Josefsson
  *
  * This file is part of GNU SASL Library.
  *
@@ -15,8 +15,8 @@
  *
  * You should have received a copy of the GNU Lesser General Public
  * License along with GNU SASL Library; if not, write to the Free
- * Software Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA
- * 02111-1307 USA
+ * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301, USA.
  *
  */
 
@@ -103,5 +103,8 @@ _gsasl_login_client_finish (Gsasl_session * sctx, void *mech_data)
 {
   struct _Gsasl_login_client_state *state = mech_data;
 
+  if (!state)
+    return;
+
   free (state);
 }
