@@ -1,5 +1,5 @@
 /* xstart.c --- Start libgsasl session.
- * Copyright (C) 2002, 2003, 2004, 2005  Simon Josefsson
+ * Copyright (C) 2002, 2003, 2004, 2005, 2006  Simon Josefsson
  *
  * This file is part of GNU SASL Library.
  *
@@ -94,7 +94,7 @@ start (Gsasl * ctx,
   res = setup (ctx, mech, out, n_mechs, mechs, clientp);
   if (res != GSASL_OK)
     {
-      free (out);
+      gsasl_finish (out);
       return res;
     }
 
